@@ -1,36 +1,26 @@
 /*
-  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
-
-  You should have received a copy of the GNU Lesser General Public
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: LGPL-2.1-or-later
 */
-#ifndef GRANTLEETHEME_H
-#define GRANTLEETHEME_H
+#pragma once
 
 #include "grantleetheme_export.h"
 
+#include <QSharedDataPointer>
 #include <QString>
 #include <QStringList>
 #include <QVariantHash>
-#include <QSharedDataPointer>
 
 class GrantleeThemeTest;
 
-namespace GrantleeTheme {
+namespace GrantleeTheme
+{
 class ThemeManager;
 class ThemePrivate;
-
+/**
+ * @brief The Theme class
+ */
 class GRANTLEETHEME_EXPORT Theme
 {
 public:
@@ -52,6 +42,8 @@ public:
     Q_REQUIRED_RESULT QString author() const;
     Q_REQUIRED_RESULT QString authorEmail() const;
 
+    void addThemePath(const QString &path);
+
     Q_REQUIRED_RESULT QString render(const QString &templateName, const QVariantHash &data, const QByteArray &applicationDomain = QByteArray());
 
     static void addPluginPath(const QString &path);
@@ -65,4 +57,3 @@ private:
 };
 }
 
-#endif // GRANTLEETHEME_H
